@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: xml-hamlet
 version: 0.4.0.11
-id: xml-hamlet-0.4.0.11-b82f858a26ddee8f8eb5ebfd4b9524a6
-key: xmlha_ElEhRh2Jbnb44vYPBMd964
+id: xml-hamlet-0.4.0.11-3c6b7527ccaa3593c4f57eea5ace7ebe
+key: xmlha_3l0kEPGjppw0eNgxfhyvrI
 license: BSD3
 maintainer: michael@snoyman.com
 homepage: http://www.yesodweb.com/
@@ -20,15 +20,15 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/xml-hamlet-0.4.0.11
 library-dirs: /usr/lib/ghc-7.10.3/site-local/xml-hamlet-0.4.0.11
 data-dir: /usr/share/arm-linux-ghc-7.10.3/xml-hamlet-0.4.0.11
-hs-libraries: HSxml-hamlet-0.4.0.11-ElEhRh2Jbnb44vYPBMd964
+hs-libraries: HSxml-hamlet-0.4.0.11-3l0kEPGjppw0eNgxfhyvrI
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
-    shakespeare-2.0.7-39cc4f42107716d9e8a539beb0a84dc6
+    parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
+    shakespeare-2.0.7-4ef2bc28a9a68fc4404a3488a8a328d3
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
-    xml-conduit-1.3.4-e268a8d251308faa5ddb6ec5be7cd100
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
+    xml-conduit-1.3.4-afe40bd27d2aaa75347b019ed922ee43
 haddock-interfaces: /usr/share/doc/haskell-xml-hamlet/html/xml-hamlet.haddock
 haddock-html: /usr/share/doc/haskell-xml-hamlet/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
